<?php
/* HTTPS link by venge@lokalsound.com
         expanded by pdontthink@angrynerds.com */

function squirrelmail_plugin_init_show_ssl_link() {

   global $squirrelmail_plugin_hooks;

   $squirrelmail_plugin_hooks['login_cookie']['show_ssl_link'] = 'ssl_link_set_session_vars';
   $squirrelmail_plugin_hooks['login_bottom']['show_ssl_link'] = 'show_ssl_link';
   $squirrelmail_plugin_hooks['webmail_top']['show_ssl_link'] = 'log_out_of_https';

}


function ssl_link_set_session_vars() {

   if (defined('SM_PATH'))
      include_once(SM_PATH . 'plugins/show_ssl_link/functions.php');
   else
      include_once('../plugins/show_ssl_link/functions.php');

   ssl_link_set_session_vars_do();

}


function show_ssl_link() {

   if (defined('SM_PATH'))
      include_once(SM_PATH . 'plugins/show_ssl_link/functions.php');
   else
      include_once('../plugins/show_ssl_link/functions.php');

   show_ssl_link_do();

}


function log_out_of_https() {

   if (defined('SM_PATH'))
      include_once(SM_PATH . 'plugins/show_ssl_link/functions.php');
   else
      include_once('../plugins/show_ssl_link/functions.php');

   log_out_of_https_do();

}


function show_ssl_link_version() {

   return '2.1';

}


?>
